"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Helpers_1 = require("../helpers/Helpers");
exports.checkScenario = function (scenario) {
    var allUnits = Helpers_1.getAllUnits(scenario);
    var allConditions = Helpers_1.getAllConditions(scenario);
    var allEffects = Helpers_1.getAllEffects(scenario);
    var unitIds = Helpers_1.getAllUnitIds(scenario);
    // Check for garisson IDs
    var notExistsGarissonIds = [];
    var notCorrectUnitCoords = [];
    var notCorrectUnitIds = [];
    allUnits.forEach(function (unit) {
        // Check for unit ID
        if (unit.id < 0 && unit.id >= scenario.compressedHeader.nextUnitId) {
            notCorrectUnitIds.push(unit);
        }
        // Check for garisson ID
        if (unit.garissonId > -1 && !unitIds.includes(unit.garissonId)) {
            notExistsGarissonIds.push(unit);
        }
        // Check for unit coords
        if (unit.x < 0 || unit.x > scenario.map.width || unit.y < 0 || unit.y >= scenario.map.height) {
            notCorrectUnitCoords.push(unit);
        }
    });
    var notExistingTriggerId = [];
    var notExistsEffectUnitId = [];
    allEffects.forEach(function (effect) {
        // Check for Effect's unit Id
        if (effect.unitId > -1 && !unitIds.includes(effect.unitId)) {
            notExistsEffectUnitId.push(effect);
        }
        // Check for Effect's unit Ids
        if (effect.unitIDs.length > 0) {
            effect.unitIDs.forEach(function (id) {
                if (id > -1 && !unitIds.includes(id)) {
                    notExistsEffectUnitId.push(effect);
                }
            });
        }
        // Check for trigger's Id
        if (effect.triggerId > -1 && effect.triggerId > scenario.triggersCount - 1) {
            notExistingTriggerId.push(effect);
        }
    });
    // Check for Condition's unit Id
    var notExistsConditionUnitId = [];
    allConditions.forEach(function (condition) {
        // Check for condition's unit Id
        if (condition.unitId > -1 && !unitIds.includes(condition.unitId)) {
            notExistsConditionUnitId.push(condition);
        }
    });
    return {
        notCorrectUnitIds: notCorrectUnitIds,
        notExistsGarissonIds: notExistsGarissonIds,
        notExistsEffectUnitId: notExistsEffectUnitId,
        notExistsConditionUnitId: notExistsConditionUnitId,
        notExistingTriggerId: notExistingTriggerId,
        notCorrectUnitCoords: notCorrectUnitCoords
    };
};
