"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * @param scenario
 * @param includeGaia - should also returns gaia units ?
 */
exports.getAllUnits = function (scenario, includeGaia) {
    if (includeGaia === void 0) { includeGaia = true; }
    return (includeGaia ? scenario.units.sections : scenario.units.sections.slice(1, 16)).reduce(function (acc, section) { return acc.concat(section.units); }, []);
};
/**
 * Get all conditions in scenario
 * @param scenario
 */
exports.getAllConditions = function (scenario) {
    return scenario.triggers.reduce(function (acc, trigger) { return acc.concat(trigger.conditions); }, []);
};
/**
 * Get all effects in scenario
 * @param scenario
 */
exports.getAllEffects = function (scenario) {
    return scenario.triggers.reduce(function (acc, trigger) { return acc.concat(trigger.effects); }, []);
};
/**
 * @param scenario
 * @param includeGaia - should also includes gaia unit ids ?
 */
exports.getAllUnitIds = function (scenario, includeGaia) {
    if (includeGaia === void 0) { includeGaia = true; }
    return exports.getAllUnits(scenario, includeGaia).reduce(function (acc, unit) { return acc.concat([unit.id]); }, []);
};
/**
 * Get only gaia units
 * @param scenario
 */
exports.getGaiaUnits = function (scenario) { return scenario.units.sections[0].units; };
/**
 * Returns scenario tiles as 2d Array
 * @param scenario
 * @desc by default, scenario tiles are stored as 1d Array
 */
exports.getMap2dArray = function (scenario) {
    var tiles = [];
    var width = scenario.map.width;
    for (var i = 0; i < scenario.map.height; i++) {
        var row = scenario.map.terrain.slice(i * width, width);
        tiles.push(row);
    }
    return tiles;
};
/**
 * Find unit by it's id
 * @param scenario
 * @param unitId
 */
exports.getUnitById = function (scenario, unitId) {
    for (var _i = 0, _a = scenario.units.sections; _i < _a.length; _i++) {
        var uSection = _a[_i];
        var foundUnit = uSection.units.find(function (unit) { return unit.id === unitId; });
        if (foundUnit) {
            return foundUnit;
        }
    }
    return null;
};
/**
 * Get tile at Row and Col
 * @param scenario
 * @param row
 * @param col
 */
exports.getTile = function (scenario, row, col) {
    return scenario.map.terrain[row * scenario.map.width + col];
};
/**
 * Receive dominant terrain Id
 * @param scenario
 */
exports.getDominantTerrain = function (scenario) {
    var dict = {};
    var dominant = ["0", 0];
    scenario.map.terrain.forEach(function (ter) {
        var id = ter[0];
        if (id in dict) {
            dict[id] = dict[id] + 1;
        }
        else {
            dict[id] = 1;
        }
    });
    Object.entries(dict).forEach(function (ter) {
        if (ter[1] > dominant[1]) {
            dominant = ter;
        }
    });
    return dominant;
};
