/// <reference types="node" />
export { ScenarioStruct } from "./Structures/ScenarioStruct";
/**
 * Read scenario file
 * @param file - scenario.scx or scenario.aoe2
 */
export declare const readScenario: (file: Buffer) => {
    header: {
        version: string;
        size: number;
        unknown1: number;
        lastSave: number;
        instructions: string;
        unknown2: number;
        players: number;
    };
    compressedHeader: {
        nextUnitId: number;
        version2: number;
        playerNames: string[];
        playerNamesIDs: number[];
        playersData: {
            active: number;
            human: number;
            civilization: number;
            CTYMode: number;
        }[];
        unknown1: number;
        unknown2: string;
        unknown3: number;
        originalFilename: string;
    };
    messages: {
        objectivesId: number;
        hintsId: number;
        victoryId: number;
        lossId: number;
        historyId: number;
        scoutId: number;
        objectivesTxt: string;
        hintsTxt: string;
        victoryTxt: string;
        lossTxt: string;
        historyTxt: string;
        scoutTxt: string;
    };
    cinematics: {
        intro: string;
        defeat: string;
        victory: string;
    };
    image: {
        filename: string;
        included: number;
        width: number;
        height: number;
        exists: number;
    };
    playersData2: {
        unknown1: [string, string][];
        aiNames: string[];
        aiFiles: {
            unknown1: number;
            unknown2: number;
            fileText: string;
        }[];
        aiType: number[];
        separator: number;
        resources: {
            gold: number;
            wood: number;
            food: number;
            stone: number;
            ore: number;
            goods: number;
        }[];
    };
    goals: {
        separator: number;
        conquest: number;
        unknown1: number;
        relics: number;
        unknown2: number;
        exploration: number;
        unknown3: number;
        all: number;
        mode: number;
        score: number;
        time: number;
    };
    diplomacy: {
        diplomacies: number[][];
        unused: number;
        separator: number;
        alliedVictories: number[];
    };
    disables: {
        disabledTechs: number[];
        disabledTechsIDs: number[][];
        disabledUnits: number[];
        disabledUnitsIDs: number[][];
        disabledBuildings: number[];
        disabledBuildingsIDs: number[][];
        combatMode: number;
        navalMode: number;
        allTechs: number;
        startingAges: number[];
    };
    map: {
        separator: number;
        startingCamera: [number, number];
        aiType: number;
        width: number;
        height: number;
        terrain: [number, number, number][];
    };
    units: {
        sectionCount: number;
        resources: {
            food: number;
            wood: number;
            gold: number;
            stone: number;
            ore: number;
            padding: number;
            population: number;
        }[];
        sections: {
            count: number;
            units: {
                x: number;
                y: number;
                unknown1: number;
                id: number;
                unit: number;
                status: number;
                rotation: number;
                initialFrame: number;
                garissonId: number;
            }[];
        }[];
    };
    playersCount: number;
    playersData4: {
        constName: string;
        startCam: [number, number];
        startCam2: [number, number];
        alliedVictory: number;
        diplomacyCount: number;
        diplomacy1: number[];
        diplomacy2: number[];
        color: number;
        unknown3: number;
        unknown4: number;
        unknown5?: number[] | undefined;
        unknown6: number[];
        unknown7: number[];
        unknown8: number;
    }[];
    triggersInstructionStart: number;
    triggersCount: number;
    triggers: {
        isEnabled: number;
        isLoop: number;
        strId: number;
        desc: number;
        descOrd: number;
        timeStart: number;
        text: string;
        name: string;
        effectCount: number;
        effects: {
            type: number;
            check: number;
            aiGoal: number;
            amount: number;
            resource: number;
            diplomacy: number;
            unitsCount: number;
            unitId: number;
            unitName: number;
            source: number;
            target: number;
            tech: number;
            instructionId: number;
            soundId: number;
            displayDuration: number;
            triggerId: number;
            location: [number, number];
            area: [number, number, number, number];
            unitGroup: number;
            unitType: number;
            instrPanel: number;
            instrText: string;
            soundFile: string;
            unitIDs: number[];
        }[];
        effectsOrd: number[];
        conditionCount: number;
        conditions: {
            type: number;
            isChecked: number;
            amount: number;
            resourceId: number;
            unitObject: number;
            unitId: number;
            unitName: number;
            sourcePlayer: number;
            techId: number;
            elapsed: number;
            unknown1: number;
            area: [number, number, number, number];
            unitGroup: number;
            unitType: number;
            aiSignal: number;
        }[];
        conditionsOrd: number[];
    }[];
    triggersOrd: number[];
};
