"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Helpers_1 = require("../helpers/Helpers");
var Cursor = /** @class */ (function () {
    function Cursor(x, y, fill) {
        this.paint = false;
        this.x = x;
        this.y = y;
        this.fill = fill;
    }
    Cursor.prototype.goto = function (x, y) {
        this.x = x;
        this.y = y;
    };
    return Cursor;
}());
exports.Cursor = Cursor;
var Paint = /** @class */ (function () {
    function Paint(scenario) {
        this._tiles = Helpers_1.getMap2dArray(scenario);
        this.cursor = new Cursor(0, 0, 0);
    }
    Object.defineProperty(Paint.prototype, "rows", {
        get: function () {
            return this._tiles.length;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Paint.prototype, "cols", {
        get: function () {
            return this._tiles[0].length;
        },
        enumerable: true,
        configurable: true
    });
    Paint.prototype._checkBounds = function (x, y) {
        if (x < 0 || x >= this.cols) {
            throw new Error("position 'x' is outside of bounds: " + x);
        }
        if (y < 0 || y >= this.rows) {
            throw new Error("position 'y' is outside of bounds: " + y);
        }
    };
    Paint.prototype.goto = function (x, y) {
        try {
            this._checkBounds(x, y);
        }
        catch (e) {
            throw new Error("cannot jump with cursor to position [" + x + ", " + y + "] because is outside of bounds");
        }
        this.cursor.goto(x, y);
    };
    Paint.prototype.point = function (x, y, fill) {
        try {
            this._checkBounds(x, y);
        }
        catch (e) {
            throw new Error("cannot point at position [" + x + ", " + y + "] because is outside of bounds");
        }
        this._tiles[y][x][0] = fill || this.cursor.fill;
    };
    /**
     * Get interpolation point between two points at magnitude
     */
    Paint.prototype.lerp = function (p1, p2, magnitude) {
        return (p2 - p1) * magnitude + p1;
    };
    /**
     * Get distance between two points
     */
    Paint.prototype.dist = function (x1, y1, x2, y2) {
        return Math.sqrt(Math.pow(x2 - x1, 2) + Math.pow(y2 - y1, 2));
    };
    /**
     * Draw line
     */
    Paint.prototype.line = function (x1, y1, x2, y2) {
        this._checkBounds(x1, y1);
        this._checkBounds(x2, y2);
        var d = this.dist(x1, y1, x2, y2) + 1;
        for (var i = 0; i < d; i++) {
            var m = 1 / d * i;
            var x = this.lerp(x1, x2, m);
            var y = this.lerp(y1, y2, m);
            this.point(x, y);
        }
    };
    /**
     * Draw box
     */
    Paint.prototype.box = function (x1, y1, w, h) {
        for (var y = y1; y < h; y++) {
            for (var x = x1; x < w; x++) {
                this.point(x, y);
            }
        }
    };
    /**
     * Draw circle
     */
    Paint.prototype.circ = function (x, y, m) {
        var res = m * Math.PI * 2;
        for (var i = 0; i < res; i++) {
            var loc = Math.PI * 2 / res * i;
            this.point(x + Math.sin(loc) * m, y + Math.cos(loc) * m / 2);
        }
    };
    return Paint;
}());
exports.Paint = Paint;
